.. include:: references.txt

.. image:: _static/gammapy_banner.png
    :width: 400px

.. Should we add a known issues section at the end?

Gammapy
-------

Gammapy is a community-developed, open-source Python package for gamma-ray
astronomy. It is a prototype for the `CTA`_ science tools. This page
(https://docs.gammapy.org ) contains the Gammapy documentation. The Gammapy
webpage ( https://gammapy.org ) contains information about Gammapy, including
news and contact information if you have any questions, want to report and issue
or request a feature, or need help with anything Gammapy-related.

.. _gammapy_intro:
.. toctree::
    :caption: Getting Started
    :maxdepth: 1

    overview
    install/index
    getting-started
    tutorials/index
    howto
    references
    changelog

.. _gammapy_package:
.. toctree::
    :caption: Gammapy Package
    :maxdepth: 1

    analysis/index
    modeling/index
    cube/index
    spectrum/index
    time/index
    detect/index
    data/index
    irf/index
    maps/index

    catalog/index
    astro/index

    stats/index
    utils/index
    scripts/index


.. _gammapy_dev:
.. toctree::
    :caption: Developer Documentation
    :titlesonly:
    :maxdepth: 1

    development/index
